==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.EventSpecificationStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateEventStatementSetImpl extends InstanceSet<CreateEventStatementSet,CreateEventStatement> implements CreateEventStatementSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setIs_implicit( m_is_implicit );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public EventSpecificationStatementSet R701_is_a_EventSpecificationStatement() throws XtumlException {
        EventSpecificationStatementSet eventspecificationstatementset = new EventSpecificationStatementSetImpl();
        for ( CreateEventStatement createeventstatement : this ) eventspecificationstatementset.add( createeventstatement.R701_is_a_EventSpecificationStatement() );
        return eventspecificationstatementset;
    }
    @Override
    public CreateSMEventStatementSet R702_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventStatement createeventstatement : this ) createsmeventstatementset.add( createeventstatement.R702_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }
    @Override
    public V_VARSet R710_result_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( CreateEventStatement createeventstatement : this ) v_varset.add( createeventstatement.R710_result_V_VAR() );
        return v_varset;
    }


    @Override
    public CreateEventStatement nullElement() {
        return CreateEventStatementImpl.EMPTY_CREATEEVENTSTATEMENT;
    }

    @Override
    public CreateEventStatementSet emptySet() {
      return new CreateEventStatementSetImpl();
    }

    @Override
    public CreateEventStatementSet value() {
        return this;
    }

    @Override
    public List<CreateEventStatement> elements() {
        return Arrays.asList(toArray(new CreateEventStatement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.EventSpecificationStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateEventStatementSetImpl extends InstanceSet<CreateEventStatementSet,CreateEventStatement> implements CreateEventStatementSet {

    public CreateEventStatementSetImpl() {
    }

    public CreateEventStatementSetImpl(Comparator<? super CreateEventStatement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setIs_implicit( m_is_implicit );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventStatement createeventstatement : this ) createeventstatement.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public EventSpecificationStatementSet R701_is_a_EventSpecificationStatement() throws XtumlException {
        EventSpecificationStatementSet eventspecificationstatementset = new EventSpecificationStatementSetImpl();
        for ( CreateEventStatement createeventstatement : this ) eventspecificationstatementset.add( createeventstatement.R701_is_a_EventSpecificationStatement() );
        return eventspecificationstatementset;
    }
    @Override
    public CreateSMEventStatementSet R702_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventStatement createeventstatement : this ) createsmeventstatementset.add( createeventstatement.R702_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }
    @Override
    public V_VARSet R710_result_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( CreateEventStatement createeventstatement : this ) v_varset.add( createeventstatement.R710_result_V_VAR() );
        return v_varset;
    }


    @Override
    public CreateEventStatement nullElement() {
        return CreateEventStatementImpl.EMPTY_CREATEEVENTSTATEMENT;
    }

    @Override
    public CreateEventStatementSet emptySet() {
      return new CreateEventStatementSetImpl();
    }

    @Override
    public CreateEventStatementSet emptySet(Comparator<? super CreateEventStatement> comp) {
      return new CreateEventStatementSetImpl(comp);
    }

    @Override
    public CreateEventStatementSet value() {
        return this;
    }

    @Override
    public List<CreateEventStatement> elements() {
        return Arrays.asList(toArray(new CreateEventStatement[0]));
    }

}
